@@ -8,6 +8,9 @@ from deepmerge import Merger
 from pyramda import *
 from json import dumps
 
+# Pick doesn't handle objects, sigh, so update below
+old_pick = pick
+
 
 @curry
 def prop(key, dct_or_obj):
@@ -48,6 +51,7 @@ def filter_dict(f, dct):
     return dict(filter(f, dct.items()))
 
 
+@curry
 def all_pass_dict(f, dct):
     """
         Returns true if all dct values pass f
@@ -197,9 +201,9 @@ def item_path_or(default, keys, dict_or_obj):
     :param dict_or_obj: A dict or obj
     :return:
     """
-    if not keys:
+    if keys == None:
         raise ValueError("Expected at least one key, got {0}".format(keys))
-    resolved_keys = keys.split('.') if isinstance(str, keys) else keys
+    resolved_keys = keys.split('.') if isinstance(str, keys) else to_array_if_not(keys)
     current_value = dict_or_obj
     for key in resolved_keys:
         current_value = prop_or(default, key, default_to({}, current_value))
@@ -323,6 +327,25 @@ def omit_deep(omit_props, dct):
     return dct
 
 
+@curry
+def pick(keys, obj):
+    """
+        Overrides pyramda pick to handle objects, not just dicts, sigh
+    :param keys:
+    :param obj:
+    :return: A dict of the picked key, values. Missing keys are omitted
+    """
+    return old_pick(keys, obj) if isinstance(dict, obj) else \
+        from_pairs(
+            compact(
+                map(
+                    lambda key: [key, getattr(key, obj)] if has(key, obj) else None,
+                    keys
+                )
+            )
+        )
+
+
 @curry
 def pick_deep(pick_dct, dct):
     """
@@ -754,6 +777,7 @@ def isalambda(v):
     return isfunction(v) and v.__name__ == '<lambda>'
 
 
+@curry
 def map_prop_value_as_index(prp, lst):
     """
         Returns the given prop of each item in the list
@@ -791,13 +815,14 @@ def to_dict_deep(obj, classkey=None):
         return obj
 
 
+@curry
 def flatten_dct_until(obj, until_func, separator):
     """
     Flattens an objects so deep keys and array indices become concatinated strings
     E.g. {a: {b: [1, 3]}} => {'a.b.0': 1, 'a.b.1': 2}
     @param {Object} obj The object to flattened
     @param {Function} until_func stop flattening a line if the this function returns false for the current key
-    Optionally takes value as a second arg if you want to test value's type
+    Takes 2 args, key and value
     @param {Object} separator Key segment separator, probably either '.' or '__'
     @returns {Object} The 1-D version of the object
     :param obj:
@@ -806,6 +831,7 @@ def flatten_dct_until(obj, until_func, separator):
     return from_pairs(_flatten_dct(obj, until_func, separator))
 
 
+@curry
 def flatten_dct(obj, separator):
     """
     Flattens an objects so deep keys and array indices become concatinated strings
@@ -915,7 +941,7 @@ def fake_lens_path_set(lens_path, value, obj):
         # Find the value at the path or create a {} or [] at obj[segment]
         found_or_created = item_path_or(
             if_else(
-                lambda segment: segment.isnumeric(),
+                lambda segment: isint(segment) or segment.isnumeric(),
                 always([]),
                 always({})
             )(head(tail(lens_path))),
@@ -926,7 +952,7 @@ def fake_lens_path_set(lens_path, value, obj):
         new_value = fake_lens_path_set(tail(lens_path), value, found_or_created)
 
     # Set or replace
-    if segment.isnumeric():
+    if isint(segment) or segment.isnumeric():
         set_array_index(int(segment), new_value, obj_copy)
     else:
         if isinstance(dict, obj_copy):
@@ -1009,6 +1035,7 @@ def unless(unless_pred, when_not_true, obj):
     return if_else(unless_pred, identity, when_not_true, obj)
 
 
+@curry
 def props(props, obj_or_dict):
     """
         Ramda implmentation of props, which fetches each specified prop in a dict or object using
@@ -1024,6 +1051,7 @@ def props(props, obj_or_dict):
     )
 
 
+@curry
 def props_or(undefined_value, props, obj_or_dict):
     """
         Ramda implmentation of props, which fetches each specified prop in a dict or object using
@@ -1040,6 +1068,7 @@ def props_or(undefined_value, props, obj_or_dict):
     )
 
 
+@curry
 def str_paths_or(undefined_value, str_paths, obj_or_dict):
     """
         Ramda implmentation of props but for string pathas,
